import numpy as np
from urllib.request import urlretrieve


URL = "https://www.ndbc.noaa.gov/data/realtime2/{}.data_spec"
DEST = "./data/{}.data_spec"

class Buoy:

    def __init__(self, buoy):
        self.buoy = buoy
        self.dates = []
        self.E = np.array([])
        self.f = np.array([])

    def get_data(self):
        url = URL.format(self.buoy)
        dest = DEST.format(self.buoy)
        urlretrieve(url,dest)
        self.dest = dest
        return dest

    def read_data(self, dest):
        dates = []
        energies = []
        frequencies = []

        with open(dest) as fp: 
            for _ in range (3):
                next(fp)

            for l in fp:
                dates.append(l.split()[0:5])
                energies.append([float(e) for e in l.split()[6::2]])
                freqs = l.split()[7::2]
                frequencies.append([float(i[1:-1]) for i in freqs])

            fp.close()

            E = np.array(energies)
            f = np.array(frequencies)
        return (E, f)



import numpy as np

class Swel:
    def __init__(self,E,f):
        self.Emid = self.calc_midpoint(E)
        self.fmid = self.calc_midpoint(f)
        self.df = np.diff(f)

    def calc_swh(self):
        product = self.df * self.Emid
        return 4 * np.sqrt(product.sum(axis=1))

    def calc_midpoint(self,series):
        nofirst = series[:, 1:]  # every element in a row, not the first
        nolast = series[:, :-1]  # every element in a row, not the last
        mid = 0.5 * (nolast + nofirst)
        return mid

    def flip(self,series):
        return series[::-1]



import os.path
from setuptools import find_packages, setup

# Package data
# ------------
_author = 'Noah Spahn'
_author_email = 'noah.de@gmail.com'
_classifiers = [
    'Environment :: Console',
    'Intended Audience :: Developers',
    'Intended Audience :: Information Technology',
    'Intended Audience :: Science/Research',
    'Topic :: Scientific/Engineering',
    'License :: OSI Approved :: Apache Software License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Topic :: Software Development :: Libraries :: Python Modules',
]
_description = 'SWEL'
_download_url = 'http://pypi.python.org/pypi/swel/'
_requirements = ["beautifulsoup4", "future", "requests", "configparser"]
_keywords = ['NOAA', 'NBDC', 'oceanography', 'earth science', 'waves']
_license = 'Apache License, Version 2.0'
_long_description = 'A python utility'
_name = 'swel'
_namespaces = []
_test_suite = 'swel.tests'
_url = 'https://github.com/noah-de/swel'
_version = '0.0.1'
_zip_safe = False

# Setup Metadata
# --------------


def _read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

_header = '*' * len(_name) + '\n' + _name + '\n' + '*' * len(_name)
_longDescription = '\n\n'.join([
    _header,
    _read('README.md')
])
open('doc.txt', 'w').write(_longDescription)


setup(
    author=_author,
    author_email=_author_email,
    classifiers=_classifiers,
    description=_description,
    download_url=_download_url,
    include_package_data=True,
    install_requires=_requirements,
    keywords=_keywords,
    license=_license,
    long_description=_long_description,
    name=_name,
    namespace_packages=_namespaces,
    packages=find_packages(),
    test_suite=_test_suite,
    url=_url,
    version=_version,
    zip_safe=_zip_safe,
)

# setup(name='swel',
#       version='0.1',
#       description='calculate significant wave height periods from raw NOAA buoy data',
#       url='https://github.com/noah-de/swel',
#       author='Noah Spahn',
#       author_email='noah.de@gmail.com	',
#       license='MIT',
#       packages=['swel'],
#       zip_safe=False)
